# Qmorse

Hmorse is a small Python library for **encoding and decoding Binary Morse code**.  
It allows you to quickly convert text to Morse code and vice versa.

## Features

- Convert text to Morse code.
- Convert Morse code back to text.
- Simple and lightweight.

## Installation

You can install Qmorse via pip:

```bash
pip install Qmorse
